@@ -797,8 +797,12 @@ CMyHttpModule::OnBeginRequest(
 					goto Finished;
 				}
 
-				modsecStatusEngineCall();
-
+				modsecReportRemoteLoadedRules();
+				if (this->status_call_already_sent == false)
+				{
+					this->status_call_already_sent = true;
+					modsecStatusEngineCall();
+				}
 			}
 			delete apppath;
 		}
@@ -1254,6 +1258,8 @@ CMyHttpModule::CMyHttpModule()
     GetSystemInfo(&sysInfo);
     m_dwPageSize = sysInfo.dwPageSize;
 
+    this->status_call_already_sent = false;
+
 	InitializeCriticalSection(&m_csLock);
 
 	modsecSetLogHook(this, Log);
@@ -1310,7 +1316,7 @@ BOOL CMyHttpModule::WriteEventViewerLog(LPCSTR szNotification, WORD category)
         // Write any strings to the Event Viewer and return.
         return ReportEvent(
             m_hEventLog,
-            category, 0, 0,
+            category, 0, 0x1,
             NULL, 1, 0, &szNotification, NULL );
     }
     return FALSE;
